/*
 * Card games
 *
 * Copyright (C) Evan Harris, 1991, 1994
 *
 * Permission is granted to freely redistribute and modify this code,
 * providing the author(s) get credit for having written it.
 */


#define QUIT			-1
#define NEWGAME			-2
#define RESTART			-3
#define SAVE			-4
#define OPEN			-5
#define UNDO			-6

#define NEW			0
#define LAST			1


void	EndDisplay(void);

void	InitRandom(unsigned char);
long	Random(long);

void	RenderMousePointer(int, int, int, int);
void	RestoreUnderMousePointer(int, int, int *);
int	SaveUnderMousePointer(int, int, int *);
